@@ -4,22 +4,20 @@ use v5.10;
 use warnings;
 use strict;
 
-our $VERSION = '1.28';
+our $VERSION = '1.30';
 
 use Padre::Logger;
 use Padre::Unload ();
 
-use Class::XSAccessor {
-	replace   => 1,
-	accessors => {
-		_ignore    => '_ignore',    # list of words to ignore
-		_speller   => '_speller',   # real text::aspell object
-		_utf_chars => '_utf_chars', # FIXME: as soon as wxWidgets/wxPerl supports
-		                            # newer version of STC:
-		                            # number of UTF8 characters
-		                            # used in calculating current possition
-	},
-};
+use Class::Accessor 'antlers';
+has _ignore  => ( is => 'rw', isa => 'Str' ); # list of words to ignore
+has _speller => ( is => 'rw', isa => 'Str' ); # real text::aspell object
+
+# FIXME: as soon as wxWidgets/wxPerl supports
+# newer version of STC:
+# number of UTF8 characters
+# used in calculating current possition
+has _utf_chars => ( is => 'rw', isa => 'Str' );
 
 my %MIMETYPE_MODE = (
 	'application/x-latex' => 'tex',
@@ -108,20 +106,13 @@ sub check {
 			next;
 		}
 
-		# if ( $speller->check($word) ) {
 		if ( $self->_speller->check($word) ) {
 			$self->_count_utf_chars($word);
 			next;
 		}
 
-		# uncomment when fixed above
-		#        next if exists $ignore->{$word};        # ignored words
-		#
-		#        # check spelling
-		#        next if $speller->check( $word );
-
 		# oops! spell mistake!
-		my $pos = pos($text) - length($word);
+		my $pos = ( pos $text ) - ( length $word );
 
 		return $word, $pos;
 	}
@@ -135,7 +126,9 @@ sub check {
 #######
 sub set_ignore_word {
 	my ( $self, $word ) = @_;
+
 	$self->_ignore->{$word} = 1;
+
 	return;
 }
 
@@ -144,6 +137,7 @@ sub set_ignore_word {
 #######
 sub get_suggestions {
 	my ( $self, $word ) = @_;
+
 	return $self->_speller->suggest($word);
 }
 
@@ -173,7 +167,7 @@ Padre::Plugin::SpellCheck::Engine - Check spelling in Padre, The Perl IDE.
 
 =head1 VERSION
 
-version 1.28
+version 1.30
 
 =head1 PUBLIC METHODS
 
